%define releasebase 7 
%define nbase fftw
%define prefix /opt/fft/%{nbase}/%{version}/%{compilertag}
%define modulepath /opt/Modules/modulefiles/

#Use as deafults if no command line inputs
%define as_limulus 1
%define use_gnu4  1
# allow --with[out] <feature> at rpm command line build
%{?_with_gnu3: %{expand: %%define use_gnu3 1}}
%{?_with_gnu4: %{expand: %%define use_gnu4 1}}
%{?_with_pgi: %{expand: %%define use_pgi 1}}
%{?_with_intel: %{expand: %%define use_intel 1}}
%{?_with_pathsc: %{expand: %%define use_pathsc 1}}
%{?_with_basement: %{expand: %%define as_basement 1}}
%{?_with_limulus: %{expand: %%define as_limulus 1}}
#pick the target
%if "1" == "%{as_basement}"
%define targetbase Basement
%else
%define targetbase Limulus
%endif
%global _compiler_load  module load %{compilertag}
%global _compiler_unload  module unload %{compilertag}

# pick the compiler
%if "1" == "%{use_gnu3}"
%define compilertag gnu3
%define openMP  --without-openmp
%define setenvs export CC=gcc; export CFLAGS='--enable-threads -O3 -D_FILE_OFFSET_BITS=64 -D_LARGEFILE64_SOURCE'; export F77=g77; export FFLAGS='--enable-threads -O3';
%else
%if "1" == "%{use_pgi}"
%define compilertag pgi
%define openMP  --with-openmp
%define	setenvs export CC=pgcc; export F77=pgf77; export OPENMP_CFLAGS='-mp'; export CFLAGS='-fastsse -O3 '; export FFLAGS='-fastsse -O3 ';
%else
%if "1" == "%{use_intel}"
%define compilertag intel
%define openMP  --with-openmp
%define setenvs export F77=ifort;   export FFLAGS='-O3 ';export CC=icc;  export CFLAGS='-O3';export OPENMP_CFLAGS='-openmp';
%else
%if "1" == "%{use_pathsc}"
%define compilertag pathsc
echo "Path Comp not implemented"
exit
%else
%define compilertag gnu4
%define openMP  --with-openmp
%define setenvs export CC=gcc; export CFLAGS='-O3 -D_FILE_OFFSET_BITS=64 -D_LARGEFILE64_SOURCE'; export F77=gfortran; export FFLAGS=' -O3'; export OPENMP_CFLAGS=-fopenmp;
%endif
%endif
%endif
%endif
# set the arch variables
%ifarch i386
%define fftw2hacks   --enable-i386-hacks 
%endif
%ifarch X86_64
%define fftw2hacks --disable-i386-hacks  
%endif

Name: %{nbase}-%{compilertag}

Summary: Fast Fourier Transform library
Version: 2.1.5
Group: %{targetbase}/Libraries
Release: %{releasebase}.%{targetbase}
License: GPL
URL: http://www.fftw.org/
Packager: deadline@basement-supercomputing.com
Vendor: Basement-Supercomputing.com
Source: %{nbase}-%{version}.tar.gz
BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
Requires: modules
BuildRequires: modules
Provides:%{nbase}-%{compilertag}=%{version}

%description
FFTW is a C subroutine library for computing the Discrete Fourier Transform
(DFT) in one or more dimensions, of both real and complex data, and of
arbitrary input size. We believe that FFTW, which is free software, should
become the FFT library of choice for most applications. Our benchmarks,
performed on on a variety of platforms, show that FFTW's performance is
typically superior to that of other publicly available FFT software.

This package also contains the header files, static libraries and development
documentation for %{name}. It has been configured to work in
the Warewulf Cluster environment. In this case only static libaries
are included. 

NOTE: This package does not include the MPI libraries. There is a 
separate package for each MPI version. 

%prep
%setup -q -c  %{nbase}-%{version}
mv %{nbase}-%{version} single
cp -a single double


%build
rpm -qf /opt/Modules/bin/modulecmd >& /dev/null
if [ $? -ne 0 ]; then
  echo "This RPM requries the BSC Modules package to build"
fi
. /etc/profile.d/modules.sh
# there is no module for gnu4, gnu3, these are default
# the module command just fails to load these modules
# and continues with the gnu compilers, a bit ugly but it works
%{_compiler_load}
%setenvs

### build double
pushd double
./configure --prefix=%{prefix}  %{openMP} %{fftw2hacks} \
	 --with-pentium-timer  
%{__make} %{?_smp_mflags}
popd
pushd single
### build single
./configure --prefix=%{prefix}  %{openMP} %{fftw2hacks} \
	--with-pentium-timer  \
	--enable-type-prefix \
	--enable-float 
%{__make} %{?_smp_mflags}
popd
%{_compiler_unload}

%install
pushd double
        make  DESTDIR=%{buildroot} install
        cp -a AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO ../
        cp -a doc/ ../
        cp -a FAQ/ ../
popd
pushd single
        make  DESTDIR=%{buildroot} install
popd
# make sure we include the fortran incude file
/bin/cp single/fortran/fftw_f77.i %{buildroot}/%{prefix}/include

# create /opt//etc/ld.so.conf.d/
echo "Creating /opt//etc/ld.so.conf.d/%{name} file"
mkdir -p %{buildroot}/opt/etc/ld.so.conf.d
cat <<EOF> %{buildroot}/opt/etc/ld.so.conf.d/%{name}-%{version}.conf
%{prefix}/lib
EOF



#create the module file
mkdir -p %{buildroot}/%{modulepath}/%{nbase}/%{version}
cat <<EOF >>%{buildroot}/%{modulepath}/%{nbase}/%{version}/%{compilertag}
#%Module1.0#######################################################################
## %{nbase} modulefile
##

proc ModulesHelp { } {
        puts stderr "\tThis module loads the appropriate environment for "
        puts stderr "\tusing %{name} version %{version}.\n"
}

module-whatis "%{name} %{version}"
module-log error none

set fftw2root  %{prefix}

if [ module-info mode load ] {
  prepend-path  LD_LIBRARY_PATH \$fftw2root/lib
	setenv FFTW2_PATH \$fftw2root/lib
	setenv FFTW2_INCLUDE \$fftw2root/include
  append-path INFOPATH \$fftw2root/info
}
if [ module-info mode remove ] {
  remove-path LD_LIBRARY_PATH \$fftw2root/lib
	unsetenv FFTW2_PATH 
	unsetenv FFTW2_INCLUDE
  remove-path INFOPATH \$fftw2root/info
}
EOF
%post
/sbin/ldconfig 2>/dev/null

%postun
/sbin/ldconfig 2>/dev/null

%clean
%{__rm} -rf %{buildroot}

%files
%defattr(-, root, root, 0755)
%doc AUTHORS COPYING COPYRIGHT ChangeLog NEWS README* TODO doc/*.gif doc/*.html doc/*.ps FAQ/fftw-faq.html/
#%doc %{_infodir}/*.info*
#%{prefix}/etc/ld.so.conf/%{nbase}-%{version}
%{prefix}/include/*.h
%{prefix}/include/*.i
%{prefix}/lib/*.a
%{prefix}/lib/*.la
%{prefix}/info/*
%{modulepath}/%{nbase}/%{version}/%{compilertag}
/opt/%{_sysconfdir}/ld.so.conf.d/%{name}-%{version}.conf

%changelog
* Fri Dec 12 2012  Douglas Eadline <deadline@basement-supercomuting.com>
- added /opt/etc/ld.so.conf.d entry

